@@ -1,6 +1,6 @@
 from shexer.utils.obj_references import check_just_one_not_none, check_one_or_zero_not_none
 
-from shexer.consts import SHEX, NT, TSV_SPO, N3, TURTLE, RDF_XML, FIXED_SHAPE_MAP, JSON_LD, RDF_TYPE
+from shexer.consts import SHEX, NT, TSV_SPO, N3, TURTLE, RDF_XML, FIXED_SHAPE_MAP, JSON_LD, RDF_TYPE, SHAPES_DEFAULT_NAMESPACE
 from shexer.utils.factories.class_profiler_factory import get_class_profiler
 from shexer.utils.factories.instance_tracker_factory import get_instance_tracker
 from shexer.utils.factories.class_shexer_factory import get_class_shexer
@@ -8,16 +8,23 @@ from shexer.utils.factories.remote_graph_factory import get_remote_graph_if_need
 from shexer.utils.factories.shape_map_factory import get_shape_map_if_needed
 from shexer.io.profile.formater.abstract_profile_serializer import AbstractProfileSerializer
 from shexer.utils.factories.shape_serializer_factory import get_shape_serializer
+from shexer.utils.namespaces import find_adequate_prefix_for_shapes_namespaces
 
 
 class Shaper(object):
 
-    def __init__(self, target_classes=None, file_target_classes=None,
-                 input_format=NT, instances_file_input=None,
-                 graph_file_input=None, graph_list_of_files_input=None,
+    def __init__(self, target_classes=None,
+                 file_target_classes=None,
+                 input_format=NT,
+                 instances_file_input=None,
+                 graph_file_input=None,
+                 graph_list_of_files_input=None,
                  raw_graph=None,
-                 url_graph_input=None, list_of_url_input=None,
-                 namespaces_dict=None, namespaces_dict_file=None,
+                 url_graph_input=None,
+                 rdflib_graph=None,
+                 list_of_url_input=None,
+                 namespaces_dict=None,
+                 # namespaces_dict_file=None,
                  instantiation_property=RDF_TYPE,
                  namespaces_to_ignore=None,
                  infer_numeric_types_for_untyped_literals=False,
@@ -35,7 +42,11 @@ class Shaper(object):
                  shape_qualifiers_mode=False,
                  namespaces_for_qualifier_props=None,
                  remove_empty_shapes=True,
-                 disable_comments=False):
+                 disable_comments=False,
+                 disable_or_statements=True,
+                 allow_opt_cardinality=True,
+                 disable_exact_cardinality=False,
+                 shapes_namespace=SHAPES_DEFAULT_NAMESPACE):
         """
 
         :param target_classes:
@@ -59,11 +70,12 @@ class Shaper(object):
                                 (raw_graph, "raw_graph"),
                                 (url_graph_input, "url_input"),
                                 (list_of_url_input, "list_of_url_input"),
-                                (url_endpoint, "url_endpoint")
+                                (url_endpoint, "url_endpoint"),
+                                (rdflib_graph, "rdflib_graph")
                                 )
 
-        check_one_or_zero_not_none((namespaces_dict, "namespaces_dict"),
-                                   (namespaces_dict_file, "namespaces_dict_file"))
+        # check_one_or_zero_not_none((namespaces_dict, "namespaces_dict"),
+        #                            (namespaces_dict_file, "namespaces_dict_file"))
 
         self._check_target_classes(target_classes=target_classes,
                                    file_target_classes=file_target_classes,
@@ -83,6 +95,7 @@ class Shaper(object):
         self._graph_list_of_files_input = graph_list_of_files_input
         self._url_graph_input = url_graph_input
         self._list_of_url_input = list_of_url_input
+        self._rdflib_graph = rdflib_graph
         self._namespaces_dict = namespaces_dict if namespaces_dict is not None else {}
         # self._namespaces_dict_file = namespaces_dict_file  # TODO Need to parse this
         self._instantiation_property = instantiation_property
@@ -98,6 +111,9 @@ class Shaper(object):
 
         self._remove_empty_shapes=remove_empty_shapes
         self._disable_comments = disable_comments
+        self._disable_or_statements = disable_or_statements
+        self._allow_opt_cardinality = allow_opt_cardinality
+        self._disable_exact_cardinality = disable_exact_cardinality
 
         self._depth_for_building_subgraph = depth_for_building_subgraph
         self._track_classes_for_entities_at_last_depth_level = track_classes_for_entities_at_last_depth_level
@@ -106,6 +122,10 @@ class Shaper(object):
         self._shape_map_format = shape_map_format
         self._shape_qualifiers_mode = shape_qualifiers_mode
         self._namespaces_for_qualifier_props = namespaces_for_qualifier_props
+        self._shapes_namespace = shapes_namespace
+
+        self._add_shapes_namespaces_to_namespaces_dict()
+
         #TODO check correctness of these last seven params
 
 
@@ -113,14 +133,18 @@ class Shaper(object):
         self._built_remote_graph = get_remote_graph_if_needed(endpoint_url=url_endpoint,
                                                               store_locally=True)
         self._built_shape_map = get_shape_map_if_needed(sm_format=self._shape_map_format,
-                                                        sgraph=self._built_remote_graph,
+                                                        remote_sgraph=self._built_remote_graph,
                                                         namespaces_prefix_dict=self._namespaces_dict,
                                                         target_classes=self._target_classes,
                                                         file_target_classes=self._file_target_classes,
                                                         shape_map_file=self._shape_map_file,
                                                         shape_map_raw=self._shape_map_raw,
                                                         instantiation_property=self._instantiation_property,
-                                                        shape_map_already_built=None)
+                                                        shape_map_already_built=None,
+                                                        rdflib_graph=self._rdflib_graph,
+                                                        raw_graph=self._raw_graph,
+                                                        input_format=self._input_format,
+                                                        source_file_graph=self._graph_file_input)
 
 
 
@@ -164,6 +188,10 @@ class Shaper(object):
         return serializer.serialize_shex()  # If string return is active, returns string.
         # Otherwise, it writes to file and returns None
 
+    def _add_shapes_namespaces_to_namespaces_dict(self):
+        self._namespaces_dict[self._shapes_namespace] = \
+            find_adequate_prefix_for_shapes_namespaces(self._namespaces_dict)
+
     def _launch_class_profiler(self):
         if self._class_profiler is None:
             self._class_profiler = self._build_class_profiler()
@@ -179,6 +207,25 @@ class Shaper(object):
             self._instance_tracker = self._build_instance_tracker()
         self._target_classes_dict = self._instance_tracker.track_instances()
 
+    def _build_class_shexer(self):
+        return get_class_shexer(class_instances_target_dict=self._target_classes_dict,
+                                class_profile_dict=self._profile,
+                                original_target_classes=self._target_classes,
+                                original_shape_map=self._built_shape_map,
+                                remove_empty_shapes=self._remove_empty_shapes,
+                                discard_useless_constraints_with_positive_closure=
+                                self._discard_useles_constraints_with_positive_closure,
+                                keep_less_specific=self._keep_less_specific,
+                                all_compliant_mode=self._all_compliant_mode,
+                                instantiation_property=self._instantiation_property,
+                                disable_or_statements=self._disable_or_statements,
+                                disable_comments=self._disable_comments,
+                                namespaces_dict=self._namespaces_dict,
+                                allow_opt_cardinality=self._allow_opt_cardinality,
+                                disable_exact_cardinality=self._disable_exact_cardinality,
+                                shapes_namespace=self._shapes_namespace
+                                )
+
     def _build_shapes_serializer(self, target_file, string_return, output_format):
         return get_shape_serializer(shapes_list=self._shape_list,
                                     target_file=target_file,
@@ -186,10 +233,6 @@ class Shaper(object):
                                     namespaces_dict=self._namespaces_dict,
                                     output_format=output_format,
                                     instantiation_property=self._instantiation_property,
-                                    all_compliant_mode=self._all_compliant_mode,
-                                    keep_less_specific=self._keep_less_specific,
-                                    discard_useless_constraints_with_positive_closure=
-                                    self._discard_useles_constraints_with_positive_closure,
                                     disable_comments=self._disable_comments)
 
     def _build_class_profiler(self):
@@ -204,6 +247,7 @@ class Shaper(object):
                                   namespaces_dict=self._namespaces_dict,
                                   url_input=self._url_graph_input,
                                   list_of_url_input=self._list_of_url_input,
+                                  rdflib_graph=self._rdflib_graph,
                                   shape_map_file=self._shape_map_file,
                                   shape_map_raw=self._shape_map_raw,
                                   track_classes_for_entities_at_last_depth_level=self._track_classes_for_entities_at_last_depth_level,
@@ -225,11 +269,13 @@ class Shaper(object):
                                     file_target_classes=self._file_target_classes,
                                     input_format=self._input_format,
                                     instantiation_property=self._instantiation_property,
+                                    infer_numeric_types_for_untyped_literals=self._infer_numeric_types_for_untyped_literals,
                                     raw_graph=self._raw_graph,
                                     all_classes_mode=self._all_classes_mode,
                                     namespaces_dict=self._namespaces_dict,
                                     url_input=self._url_graph_input,
                                     list_of_url_input=self._list_of_url_input,
+                                    rdflib_graph=self._rdflib_graph,
                                     shape_map_file=self._shape_map_file,
                                     shape_map_raw=self._shape_map_raw,
                                     track_classes_for_entities_at_last_depth_level=self._track_classes_for_entities_at_last_depth_level,
@@ -240,15 +286,9 @@ class Shaper(object):
                                     namespaces_for_qualifier_props=self._namespaces_for_qualifier_props,
                                     shape_qualifiers_mode=self._shape_qualifiers_mode,
                                     built_remote_graph=self._built_remote_graph,
-                                    built_shape_map=self._built_shape_map)
+                                    built_shape_map=self._built_shape_map,
+                                    shapes_namespace=self._shapes_namespace)
 
-    def _build_class_shexer(self):
-        return get_class_shexer(class_instances_target_dict=self._target_classes_dict,
-                                class_profile_dict=self._profile,
-                                original_target_classes=self._target_classes,
-                                original_shape_map=self._built_shape_map,
-                                remove_empty_shapes=self._remove_empty_shapes
-                                )
 
     @staticmethod
     def _check_correct_output_params(string_output, target_file):
