@@ -1,4 +1,4 @@
-from shexer.consts import NT, FIXED_SHAPE_MAP
+from shexer.consts import NT, FIXED_SHAPE_MAP, SHAPES_DEFAULT_NAMESPACE
 from shexer.utils.factories.triple_yielders_factory import get_triple_yielder, tune_target_classes_if_needed, \
     read_target_classes_from_file
 from shexer.core.instances.instance_tracker import InstanceTracker
@@ -8,18 +8,21 @@ from shexer.utils.factories.iri_factory import create_IRIs_from_string_list
 from shexer.utils.factories.shape_map_parser_factory import get_shape_map_parser
 from shexer.model.graph.endpoint_sgraph import EndpointSGraph
 from shexer.model.graph.rdflib_sgraph import RdflibSgraph
+from shexer.utils.dict import reverse_keys_and_values
 
 
 def get_instance_tracker(instances_file_input=None, graph_file_input=None,
                          graph_list_of_files_input=None, target_classes=None,
                          file_target_classes=None, input_format=NT,
                          instantiation_property=None,
+                         infer_numeric_types_for_untyped_literals=None,
                          namespaces_to_ignore=None,
                          raw_graph=None,
                          all_classes_mode=False,
                          namespaces_dict=None,
                          url_input=None,
                          list_of_url_input=None,
+                         rdflib_graph=None,
                          shape_map_file=None,
                          shape_map_raw=None,
                          shape_map_format=FIXED_SHAPE_MAP,
@@ -30,7 +33,8 @@ def get_instance_tracker(instances_file_input=None, graph_file_input=None,
                          namespaces_for_qualifier_props=None,
                          shape_qualifiers_mode=False,
                          built_remote_graph=None,
-                         built_shape_map=None
+                         built_shape_map=None,
+                         shapes_namespace=SHAPES_DEFAULT_NAMESPACE
                          ):
     """
 
@@ -61,6 +65,7 @@ def get_instance_tracker(instances_file_input=None, graph_file_input=None,
     :return:
     """
 
+    prefix_namespaces_dict = reverse_keys_and_values(namespaces_dict)
     instance_yielder = None
     if instances_file_input is not None:
         instance_yielder = get_triple_yielder(source_file=instances_file_input,
@@ -68,8 +73,10 @@ def get_instance_tracker(instances_file_input=None, graph_file_input=None,
                                               namespaces_to_ignore=namespaces_to_ignore,
                                               raw_graph=raw_graph,
                                               namespaces_dict=namespaces_dict,
+                                              allow_untyped_numbers=infer_numeric_types_for_untyped_literals,
                                               url_input=url_input,
                                               list_of_url_input=list_of_url_input,
+                                              rdflib_graph=rdflib_graph,
                                               instantiation_property=instantiation_property,
                                               shape_map_file=shape_map_file,
                                               shape_map_raw=shape_map_raw,
@@ -90,8 +97,10 @@ def get_instance_tracker(instances_file_input=None, graph_file_input=None,
                                               namespaces_to_ignore=namespaces_to_ignore,
                                               raw_graph=raw_graph,
                                               namespaces_dict=namespaces_dict,
+                                              allow_untyped_numbers=infer_numeric_types_for_untyped_literals,
                                               url_input=url_input,
                                               list_of_url_input=list_of_url_input,
+                                              rdflib_graph=rdflib_graph,
                                               instantiation_property=instantiation_property,
                                               shape_map_file=shape_map_file,
                                               shape_map_raw=shape_map_raw,
@@ -127,7 +136,10 @@ def get_instance_tracker(instances_file_input=None, graph_file_input=None,
         model_classes = None
         if file_target_classes or target_classes is not None:
             list_of_str_target_classes = tune_target_classes_if_needed(
-                target_classes) if target_classes is not None else read_target_classes_from_file(file_target_classes)
+                list_target_classes=target_classes,
+                prefix_namespaces_dict=prefix_namespaces_dict) if target_classes is not None else read_target_classes_from_file(
+                file_target_classes=file_target_classes,
+                prefix_namespaces_dict=prefix_namespaces_dict)
             model_classes = get_list_of_model_classes(list_of_str_target_classes)
 
         pure_instances_tracker = InstanceTracker(target_classes=model_classes,
@@ -136,7 +148,8 @@ def get_instance_tracker(instances_file_input=None, graph_file_input=None,
                                                  all_classes_mode=all_classes_mode,
                                                  track_hierarchies=False,
                                                  namespaces_for_qualifier_props=namespaces_for_qualifier_props,
-                                                 shape_qualifiers_mode=shape_qualifiers_mode)
+                                                 shape_qualifiers_mode=shape_qualifiers_mode,
+                                                 shapes_namespace=shapes_namespace)
 
     return _decide_tracker_to_return(selectors_tracker, pure_instances_tracker)
 
@@ -149,6 +162,7 @@ def _get_adequate_sgraph(endpoint_url, graph_file_input, url_input, graph_format
                             raw_graph=raw_graph,
                             format=graph_format)
 
+
 def _decide_tracker_to_return(selectors_tracker, pure_instances_tracker):
     if selectors_tracker is not None and pure_instances_tracker is not None:
         return MixedInstanceTracker(list_of_instance_trackers=[selectors_tracker, pure_instances_tracker])
@@ -169,6 +183,3 @@ def _are_there_some_target_classes(target_classes, file_target_classes, all_clas
 
 def get_list_of_model_classes(list_of_str_target_classes):
     return create_IRIs_from_string_list(list_of_str_target_classes)
-
-
-
